@@ -1,56 +1,55 @@
 #ifndef AMPL_DATAFRAME_H
 #define AMPL_DATAFRAME_H
 
-#include "ampl/ep/dataframe_ep.h"
-#include "ampl/ep/errorinfo_ep.h"
-#include "ampl/ep/declarations.h"
-#include "ampl/ep/scopedarray.h"
-
-#include "ampl/tuple.h"
 #include "ampl/ep/arg.h"
+#include "ampl/ep/dataframe_ep.h"
+#include "ampl/ep/declarations.h"
+#include "ampl/ep/errorinfo_ep.h"
+#include "ampl/ep/scopedarray.h"
 #include "ampl/ep/slice.h"
 #include "ampl/string.h"
+#include "ampl/tuple.h"
 
 namespace ampl {
 
 class EntityArgs;
 
 /**
-* A DataFrame object, used to communicate data to and from the %AMPL entities.
-*
-* An object of this class can be used to do the following tasks:
-*
-* <ul>
-* <li>Assign values to %AMPL entities (once the DataFrame is populated, use
-* AMPL::setData() to assign its values to the modelling entities in
-* its columns)
-* <li>Get values from %AMPL, decoupling the values from the %AMPL entities they
-* originate via Entity::getValues()
-* </ul>
-*
-* <p>
-* A DataFrame object can be created in various ways.
-* <ul>
-* <li>Create a skeleton via DataFrame(std::size_t numberOfIndexColumns, StringArgs headers),
-* specifiying manually the number of indexing columns and the column headers.
-* <li>Get column names (and number of indexing columns) from entities of the API, using the constructor
-* DataFrame(const EntityArgs &headers).
-* <li>Get values from AMPL, decoupling the values from the %AMPL entities they
-* originate from (via Entity::getValues())
-* </ul>
-* <p>
-* Populating a DataFrame object can be done adding row by row to a pre-existing
-* skeleton via DataFrame.addRow(), setting whole columns of a
-* pre-existing skeleton via DataFrame.setColumn() or adding columns
-* (including indexing columns) via DataFrame.addColumn().
-* <p>
-* Modifying a DataFrame object can be done via DataFrame.setColumn method.
-* <p>
-* Accessing data in a DataFrame can be done row by row using
-* DataFrame.getRow() or by column via DataFrame.getColumn().
-*/
+ * A DataFrame object, used to communicate data to and from the %AMPL entities.
+ *
+ * An object of this class can be used to do the following tasks:
+ *
+ * <ul>
+ * <li>Assign values to %AMPL entities (once the DataFrame is populated, use
+ * AMPL::setData() to assign its values to the modelling entities in
+ * its columns)
+ * <li>Get values from %AMPL, decoupling the values from the %AMPL entities they
+ * originate via Entity::getValues()
+ * </ul>
+ *
+ * <p>
+ * A DataFrame object can be created in various ways.
+ * <ul>
+ * <li>Create a skeleton via DataFrame(std::size_t numberOfIndexColumns,
+ * StringArgs headers), specifiying manually the number of indexing columns and
+ * the column headers. <li>Get column names (and number of indexing columns)
+ * from entities of the API, using the constructor DataFrame(const EntityArgs
+ * &headers). <li>Get values from AMPL, decoupling the values from the %AMPL
+ * entities they originate from (via Entity::getValues())
+ * </ul>
+ * <p>
+ * Populating a DataFrame object can be done adding row by row to a pre-existing
+ * skeleton via DataFrame.addRow(), setting whole columns of a
+ * pre-existing skeleton via DataFrame.setColumn() or adding columns
+ * (including indexing columns) via DataFrame.addColumn().
+ * <p>
+ * Modifying a DataFrame object can be done via DataFrame.setColumn method.
+ * <p>
+ * Accessing data in a DataFrame can be done row by row using
+ * DataFrame.getRow() or by column via DataFrame.getColumn().
+ */
 class DataFrame {
-public:
+ public:
   /**
   Represents a row in a DataFrame
   */
@@ -61,8 +60,8 @@ public:
   typedef internal::Slice<false> Column;
 
   /**
-  * Create a new DataFrame with the specified number of indices.
-  */
+   * Create a new DataFrame with the specified number of indices.
+   */
   explicit DataFrame(std::size_t numberOfIndexColumns) {
     impl_ = internal::AMPL_DataFrame_Create_2(numberOfIndexColumns,
                                               internal::ErrorInfo());
@@ -89,8 +88,8 @@ public:
     if (numberOfIndexColumns > headers.size())
       throw std::invalid_argument("Invalid number of indices.");
     impl_ = internal::AMPL_DataFrame_Create(
-      numberOfIndexColumns, headers.size() - numberOfIndexColumns,
-      headers.args(), internal::ErrorInfo());
+        numberOfIndexColumns, headers.size() - numberOfIndexColumns,
+        headers.args(), internal::ErrorInfo());
   }
 
   /**
@@ -111,7 +110,9 @@ public:
   /**
   Copy constructor (deep copy)
   */
-  DataFrame(const DataFrame& other) { impl_ = internal::AMPL_DataFrame_Copy(other.impl_, internal::ErrorInfo()); }
+  DataFrame(const DataFrame& other) {
+    impl_ = internal::AMPL_DataFrame_Copy(other.impl_, internal::ErrorInfo());
+  }
 
   /**
   Assignment operator (deep copies all the data)
@@ -119,7 +120,7 @@ public:
   DataFrame& operator=(const DataFrame& df) {
     if (this != &df) {
       internal::DataFrame* newDf =
-        internal::AMPL_DataFrame_Copy(df.impl_, internal::ErrorInfo());
+          internal::AMPL_DataFrame_Copy(df.impl_, internal::ErrorInfo());
       internal::AMPL_DataFrame_Destroy(impl_);
       impl_ = newDf;
     }
@@ -129,16 +130,16 @@ public:
   /**
   Equality check
   */
-  bool operator==(const DataFrame &other) const {
+  bool operator==(const DataFrame& other) const {
     return internal::AMPL_DataFrame_Equals(impl_, other.impl_,
-      internal::ErrorInfo()) != 0;
+                                           internal::ErrorInfo()) != 0;
   }
   /**
   Inequality check
   */
-  bool operator!=(const DataFrame &other) const {
+  bool operator!=(const DataFrame& other) const {
     return internal::AMPL_DataFrame_Equals(impl_, other.impl_,
-      internal::ErrorInfo()) == 0;
+                                           internal::ErrorInfo()) == 0;
   }
 
   /**
@@ -146,13 +147,17 @@ public:
    of values)
    \return	The number of columns.
    */
-  std::size_t getNumCols() const { return internal::AMPL_DataFrame_getNumCols(impl_); }
+  std::size_t getNumCols() const {
+    return internal::AMPL_DataFrame_getNumCols(impl_);
+  }
 
   /**
    Get the number of data rows in this dataframe.
    \return	The number of rows.
    */
-  std::size_t getNumRows() const { return internal::AMPL_DataFrame_getNumRows(impl_); }
+  std::size_t getNumRows() const {
+    return internal::AMPL_DataFrame_getNumRows(impl_);
+  }
 
   /**
    std::size_t DataFrame::getNumIndices() const Get the number of indices
@@ -160,8 +165,9 @@ public:
    \return	The number of indices needed to access one row of this
    dataframe.
    */
-  std::size_t getNumIndices() const { return internal::AMPL_DataFrame_getNumIndices(impl_); }
-
+  std::size_t getNumIndices() const {
+    return internal::AMPL_DataFrame_getNumIndices(impl_);
+  }
 
   /**
    Add a row to the DataFrame. The size of the tuple must be equal to the
@@ -170,8 +176,7 @@ public:
    added.
    */
   void addRow(TupleRef value) {
-    internal::AMPL_DataFrame_addRow(impl_, value.impl(),
-                                    internal::ErrorInfo());
+    internal::AMPL_DataFrame_addRow(impl_, value.impl(), internal::ErrorInfo());
   }
 
   /**
@@ -221,14 +226,17 @@ public:
    accessed, they still have to be added via DataFrame::addRow.
    \param	numRows	Number of rows to be allocated.
    */
-  void reserve(std::size_t numRows) { internal::AMPL_DataFrame_reserve(impl_, numRows, internal::ErrorInfo()); }
+  void reserve(std::size_t numRows) {
+    internal::AMPL_DataFrame_reserve(impl_, numRows, internal::ErrorInfo());
+  }
 
   /**
    Give a tabular string representation of the dataframe object.
    \return	A std::string that represents this object
    */
   std::string toString() const {
-    char* returned = internal::AMPL_DataFrame_toString(impl_, internal::ErrorInfo());
+    char* returned =
+        internal::AMPL_DataFrame_toString(impl_, internal::ErrorInfo());
     return internal::getStringFromDLL(returned);
   }
 
@@ -242,54 +250,55 @@ public:
   }
 
   /**
-  * Add a new column with the corresponding header and values to the dataframe
-  * \param header The name of the new column
-  * \param values An array of size getNumRows() with all the values of the new row
-  */
+   * Add a new column with the corresponding header and values to the dataframe
+   * \param header The name of the new column
+   * \param values An array of size getNumRows() with all the values of the new
+   * row
+   */
   void addColumn(fmt::CStringRef header, internal::Args values) {
     internal::AMPL_DataFrame_addColumn(impl_, header.c_str(), values.data(),
                                        internal::ErrorInfo());
   }
 
   /**
-  * Get the specified column as a view object
-  * \param	header	The header of the column.
-  */
+   * Get the specified column as a view object
+   * \param	header	The header of the column.
+   */
   Column getColumn(fmt::CStringRef header) const {
     return Column(impl_, internal::AMPL_DataFrame_getColumnIndex(
-                    impl_, header.c_str(), internal::ErrorInfo()));
+                             impl_, header.c_str(), internal::ErrorInfo()));
   }
   /**
-  * Set the value at the specified row and columnn
-  * \param rowIndex A tuple identiying the row to modify
-  * \param colHeader The header of the column to modify
-  * \param value The value to assign
-  */
-  void setValue(TupleRef rowIndex, fmt::CStringRef colHeader, ampl::VariantRef value)
-  {
-    internal::AMPL_DataFrame_setValue(impl_, rowIndex.impl(), colHeader.c_str(), value.impl(), internal::ErrorInfo());
+   * Set the value at the specified row and columnn
+   * \param rowIndex A tuple identiying the row to modify
+   * \param colHeader The header of the column to modify
+   * \param value The value to assign
+   */
+  void setValue(TupleRef rowIndex, fmt::CStringRef colHeader,
+                ampl::VariantRef value) {
+    internal::AMPL_DataFrame_setValue(impl_, rowIndex.impl(), colHeader.c_str(),
+                                      value.impl(), internal::ErrorInfo());
   }
   /**
-  * Set the value at the specified row and columnn
-  * \param rowIndex The 0-based index of the row to modify
-  * \param colIndex The 0-based index of the column to modify (including indices)
-  * \param value The value to assign
-  */
-  void setValue(std::size_t rowIndex, size_t colIndex, ampl::VariantRef value)
-  {
-    internal::AMPL_DataFrame_setValueByIndex(impl_, rowIndex, colIndex, value.impl(), internal::ErrorInfo());
+   * Set the value at the specified row and columnn
+   * \param rowIndex The 0-based index of the row to modify
+   * \param colIndex The 0-based index of the column to modify (including
+   * indices) \param value The value to assign
+   */
+  void setValue(std::size_t rowIndex, size_t colIndex, ampl::VariantRef value) {
+    internal::AMPL_DataFrame_setValueByIndex(
+        impl_, rowIndex, colIndex, value.impl(), internal::ErrorInfo());
   }
 
-
   /**
-  * Set the values of a column
-  * \param	header	The header of the column to be set
-  * \param	column	The values to set.
-  * \param n		The number of items in the column.
-  */
+   * Set the values of a column
+   * \param	header	The header of the column to be set
+   * \param	column	The values to set.
+   * \param n		The number of items in the column.
+   */
   void setColumn(fmt::CStringRef header, internal::Args column, std::size_t n) {
-    internal::AMPL_DataFrame_setColumn_arg(impl_, header.c_str(), column.data(), n,
-                                           internal::ErrorInfo());
+    internal::AMPL_DataFrame_setColumn_arg(impl_, header.c_str(), column.data(),
+                                           n, internal::ErrorInfo());
   }
 
   /**
@@ -331,15 +340,23 @@ public:
   /**
   Iterates through the DataFrame in a row-by-row fashion
   */
-  class iterator : public std::iterator<std::forward_iterator_tag, Row> {
+  class iterator {
+   public:
+    using iterator_category = std::forward_iterator_tag;
+    using value_type = Row;
+    using difference_type = std::ptrdiff_t;
+    using pointer = value_type*;
+    using reference = value_type&;
+
+   private:
     friend class DataFrame;
     internal::DataFrame* ptr_;
     std::size_t index_;
 
     iterator(internal::DataFrame* ptr, std::size_t index)
-      : ptr_(ptr), index_(index) {}
+        : ptr_(ptr), index_(index) {}
 
-  public:
+   public:
     /**
     Dereferences the iterator, gets a DataFrame::Row
     */
@@ -377,27 +394,27 @@ public:
   };
 
   /**
-  * Get the iterator to the first row in this DataFrame
-  */
+   * Get the iterator to the first row in this DataFrame
+   */
   iterator begin() const { return iterator(impl_, 0); }
 
   /**
-  * Get the iterator to the last row in this DataFrame (an iterator
-  * of numerical index DataFrame::getNumRows).
-  */
+   * Get the iterator to the last row in this DataFrame (an iterator
+   * of numerical index DataFrame::getNumRows).
+   */
   iterator end() const { return iterator(impl_, getNumRows()); }
 
   /**
-  * Get the iterator to the specified row in this DataFrame.
-  * \param index The index of the Row to be found
-  * \return An iterator pointing to the found row, or iterator::end if not
-  * found.
-  */
+   * Get the iterator to the specified row in this DataFrame.
+   * \param index The index of the Row to be found
+   * \return An iterator pointing to the found row, or iterator::end if not
+   * found.
+   */
   iterator find(TupleRef index) const {
     return iterator(impl_, AMPL_DataFrame_getRowIndex(impl_, index.impl(),
                                                       internal::ErrorInfo()));
   }
-  #endif
+#endif
   /**
    * Get the headers of this DataFrame
    * \return	The headers of this DataFrame
@@ -405,42 +422,42 @@ public:
 
   StringRefArray getHeaders() const {
     std::size_t size;
-    const char** ref =
-      internal::AMPL_DataFrame_getHeaders(impl_, &size, internal::ErrorInfo());
+    const char** ref = internal::AMPL_DataFrame_getHeaders(
+        impl_, &size, internal::ErrorInfo());
     return StringRefArray(ref, size);
   }
 
   /**
-  * Set the values of a DataFrame from an array of doubles.
-  * The DataFrame must have one index and one data column.
-  * \param indices The indices of the values to set
-  * \param values  An array containing the values to be set
-  */
+   * Set the values of a DataFrame from an array of doubles.
+   * The DataFrame must have one index and one data column.
+   * \param indices The indices of the values to set
+   * \param values  An array containing the values to be set
+   */
   template <std::size_t NR>
   void setArray(internal::Args indices, const double (&values)[NR]) {
     internal::AMPL_DataFrame_setArray(impl_, values, NR, indices.data(),
                                       internal::ErrorInfo());
   }
-  #ifndef SWIG
+#ifndef SWIG
   /**
-  * Set the values of a DataFrame from an array of string literals.
-  * The DataFrame must have one index and one data column.
-  * \param indices The indices of the values to set
-  * \param values  An array containing the values to be set
-  */
+   * Set the values of a DataFrame from an array of string literals.
+   * The DataFrame must have one index and one data column.
+   * \param indices The indices of the values to set
+   * \param values  An array containing the values to be set
+   */
   template <std::size_t NR>
-  void setArray(internal::Args indices, const char*(&values)[NR]) {
+  void setArray(internal::Args indices, const char* (&values)[NR]) {
     internal::AMPL_DataFrame_setArray_str(impl_, values, NR, indices.data(),
                                           internal::ErrorInfo());
   }
 #endif
   /**
-  * Set the values of a DataFrame from an array of doubles.
-  * The DataFrame must have one index and one data column.
-  * \param size The size of the two arrays passed
-  * \param indices The indices of the values to set
-  * \param values  An array containing the values to be set
-  */
+   * Set the values of a DataFrame from an array of doubles.
+   * The DataFrame must have one index and one data column.
+   * \param size The size of the two arrays passed
+   * \param indices The indices of the values to set
+   * \param values  An array containing the values to be set
+   */
   void setArray(std::size_t size, internal::Args indices,
                 const double* values) {
     internal::AMPL_DataFrame_setArray(impl_, values, size, indices.data(),
@@ -448,80 +465,80 @@ public:
   }
 
   /**
-  * Set the values of a DataFrame from an array of string literals.
-  * The DataFrame must have one index and one data column.
-  * \param size The size of the two arrays passed
-  * \param indices The indices of the values to set
-  * \param values  An array containing the values to be set
-  */
+   * Set the values of a DataFrame from an array of string literals.
+   * The DataFrame must have one index and one data column.
+   * \param size The size of the two arrays passed
+   * \param indices The indices of the values to set
+   * \param values  An array containing the values to be set
+   */
   void setArray(std::size_t size, internal::Args indices,
-                const char*const * values) {
+                const char* const* values) {
     internal::AMPL_DataFrame_setArray_str(impl_, values, size, indices.data(),
                                           internal::ErrorInfo());
   }
 
   /**
-  * Set a matrix of doubles to an empty DataFrame.
-  * The DataFrame must have two indices and one data column.
-  * \param indices0 The values of the first indexing column
-  * \param indices1 The values of the second indexing column
-  * \param values a 2d-array of doubles
-  */
+   * Set a matrix of doubles to an empty DataFrame.
+   * The DataFrame must have two indices and one data column.
+   * \param indices0 The values of the first indexing column
+   * \param indices1 The values of the second indexing column
+   * \param values a 2d-array of doubles
+   */
   template <std::size_t NR, std::size_t NC>
   void setMatrix(internal::Args indices0, internal::Args indices1,
                  const double (&values)[NR][NC]) {
     internal::AMPL_DataFrame_setMatrix(
-      impl_, reinterpret_cast<const double *>(values), NR, indices0.data(), NC,
-      indices1.data(), internal::ErrorInfo());
+        impl_, reinterpret_cast<const double*>(values), NR, indices0.data(), NC,
+        indices1.data(), internal::ErrorInfo());
   }
 #ifndef SWIG
   /**
-  * Set a matrix of strings to an empty DataFrame.
-  * The DataFrame must have two indices and one data column.
-  * \param indices0 The values of the first indexing column
-  * \param indices1 The values of the second indexing column
-  * \param values a 2d-array of string literals
-  */
+   * Set a matrix of strings to an empty DataFrame.
+   * The DataFrame must have two indices and one data column.
+   * \param indices0 The values of the first indexing column
+   * \param indices1 The values of the second indexing column
+   * \param values a 2d-array of string literals
+   */
   template <std::size_t NR, std::size_t NC>
   void setMatrix(internal::Args indices0, internal::Args indices1,
-                 const char*(&values)[NR][NC]) {
+                 const char* (&values)[NR][NC]) {
     internal::AMPL_DataFrame_setMatrix_str(
-      impl_, reinterpret_cast<const char *const *>(values), NR,
-      indices0.data(), NC, indices1.data(), internal::ErrorInfo());
+        impl_, reinterpret_cast<const char* const*>(values), NR,
+        indices0.data(), NC, indices1.data(), internal::ErrorInfo());
   }
 #endif
   /**
-  * Set a matrix of doubles to an empty DataFrame.
-  * The DataFrame must have two indices and one data column.
-  * \param num_rows The size of the first dimension (number of rows)
-  * \param row_indices The values of the first indexing column
-  * \param num_cols The size of the second dimension (number of columns)
-  * \param indices_cols The values of the second indexing column
-  * \param values a 2d-array of doubles
-  */
+   * Set a matrix of doubles to an empty DataFrame.
+   * The DataFrame must have two indices and one data column.
+   * \param num_rows The size of the first dimension (number of rows)
+   * \param row_indices The values of the first indexing column
+   * \param num_cols The size of the second dimension (number of columns)
+   * \param indices_cols The values of the second indexing column
+   * \param values a 2d-array of doubles
+   */
   void setMatrix(std::size_t num_rows, internal::Args row_indices,
                  std::size_t num_cols, internal::Args indices_cols,
                  const double* values) {
     internal::AMPL_DataFrame_setMatrix(
-      impl_, values, num_rows, row_indices.data(), num_cols,
-      indices_cols.data(), internal::ErrorInfo());
+        impl_, values, num_rows, row_indices.data(), num_cols,
+        indices_cols.data(), internal::ErrorInfo());
   }
 
   /**
-  * Set a matrix of string literals to an empty DataFrame.
-  * The DataFrame must have two indices and one data column.
-  * \param num_rows The size of the first dimension (number of rows)
-  * \param row_indices The values of the first indexing column
-  * \param num_cols The size of the second dimension (number of columns)
-  * \param indices_cols The values of the second indexing column
-  * \param values a 2d-array of strings
-  */
+   * Set a matrix of string literals to an empty DataFrame.
+   * The DataFrame must have two indices and one data column.
+   * \param num_rows The size of the first dimension (number of rows)
+   * \param row_indices The values of the first indexing column
+   * \param num_cols The size of the second dimension (number of columns)
+   * \param indices_cols The values of the second indexing column
+   * \param values a 2d-array of strings
+   */
   void setMatrix(std::size_t num_rows, internal::Args row_indices,
                  std::size_t num_cols, internal::Args indices_cols,
-                 const char*const * values) {
+                 const char* const* values) {
     internal::AMPL_DataFrame_setMatrix_str(
-      impl_, values, num_rows, row_indices.data(), num_cols,
-      indices_cols.data(), internal::ErrorInfo());
+        impl_, values, num_rows, row_indices.data(), num_cols,
+        indices_cols.data(), internal::ErrorInfo());
   }
 
   /**
@@ -529,14 +546,14 @@ public:
   */
   internal::DataFrame* impl() const { return impl_; }
 
-private:
+ private:
   internal::DataFrame* impl_;
 };
 
-}
+}  // namespace ampl
 
-#include "ampl/entity.h" // NOTE: keep this line out of "namespace ampl"
-                         // in order to avoid very long STL error messages
+#include "ampl/entity.h"  // NOTE: keep this line out of "namespace ampl"
+                          // in order to avoid very long STL error messages
 
 namespace ampl {
 
@@ -544,10 +561,10 @@ inline DataFrame::DataFrame(const EntityArgs& headers) {
   if (headers.size() == 0)
     throw std::invalid_argument("Cannot have a DataFrame without headers.");
 
-  impl_ = internal::AMPL_DataFrame_Create_3(
-    headers.getArgs(), headers.size(), internal::ErrorInfo());
+  impl_ = internal::AMPL_DataFrame_Create_3(headers.getArgs(), headers.size(),
+                                            internal::ErrorInfo());
 }
 
-}
+}  // namespace ampl
 
 #endif  // AMPL_DATAFRAME_H
