@@ -39,37 +39,37 @@
 #include <cstddef>  // for std::ptrdiff_t
 
 #if defined(_WIN32) && defined(__MINGW32__)
-# include <cstring>
+#include <cstring>
 #endif
 
 #if FMT_USE_WINDOWS_H
-# if !defined(FMT_HEADER_ONLY) && !defined(WIN32_LEAN_AND_MEAN)
-#  define WIN32_LEAN_AND_MEAN
-# endif
-# if defined(NOMINMAX) || defined(FMT_WIN_MINMAX)
-#  include <windows.h>
-# else
-#  define NOMINMAX
-#  include <windows.h>
-#  undef NOMINMAX
-# endif
+#if !defined(FMT_HEADER_ONLY) && !defined(WIN32_LEAN_AND_MEAN)
+#define WIN32_LEAN_AND_MEAN
+#endif
+#if defined(NOMINMAX) || defined(FMT_WIN_MINMAX)
+#include <windows.h>
+#else
+#define NOMINMAX
+#include <windows.h>
+#undef NOMINMAX
+#endif
 #endif
 
 #if FMT_EXCEPTIONS
-# define FMT_TRY try
-# define FMT_CATCH(x) catch (x)
+#define FMT_TRY try
+#define FMT_CATCH(x) catch (x)
 #else
-# define FMT_TRY if (true)
-# define FMT_CATCH(x) if (false)
+#define FMT_TRY if (true)
+#define FMT_CATCH(x) if (false)
 #endif
 
 #ifdef _MSC_VER
-# pragma warning(push)
-# pragma warning(disable: 4127)  // conditional expression is constant
-# pragma warning(disable: 4702)  // unreachable code
+#pragma warning(push)
+#pragma warning(disable : 4127)  // conditional expression is constant
+#pragma warning(disable : 4702)  // unreachable code
 // Disable deprecation warning for strerror. The latter is not called but
 // MSVC fails to detect it.
-# pragma warning(disable: 4996)
+#pragma warning(disable : 4996)
 #endif
 
 // Dummy implementations of strerror_r and strerror_s called if corresponding
@@ -90,7 +90,7 @@ FMT_FUNC SystemError::~SystemError() FMT_DTOR_NOEXCEPT {}
 namespace {
 
 #ifndef _MSC_VER
-# define FMT_SNPRINTF snprintf
+#define FMT_SNPRINTF snprintf
 #else  // _MSC_VER
 inline int fmt_snprintf(char *buffer, size_t size, const char *format, ...) {
   va_list args;
@@ -99,14 +99,14 @@ inline int fmt_snprintf(char *buffer, size_t size, const char *format, ...) {
   va_end(args);
   return result;
 }
-# define FMT_SNPRINTF fmt_snprintf
+#define FMT_SNPRINTF fmt_snprintf
 #endif  // _MSC_VER
 
 #if defined(_WIN32) && defined(__MINGW32__) && !defined(__NO_ISOCEXT)
-# define FMT_SWPRINTF snwprintf
+#define FMT_SWPRINTF snwprintf
 #else
-# define FMT_SWPRINTF swprintf
-#endif // defined(_WIN32) && defined(__MINGW32__) && !defined(__NO_ISOCEXT)
+#define FMT_SWPRINTF swprintf
+#endif  // defined(_WIN32) && defined(__MINGW32__) && !defined(__NO_ISOCEXT)
 
 const char RESET_COLOR[] = "\x1b[0m";
 
@@ -121,8 +121,8 @@ typedef void (*FormatFunc)(Writer &, int, StringRef);
 //   ERANGE - buffer is not large enough to store the error message
 //   other  - failure
 // Buffer should be at least of size 1.
-int safe_strerror(
-    int error_code, char *&buffer, std::size_t buffer_size) FMT_NOEXCEPT {
+int safe_strerror(int error_code, char *&buffer,
+                  std::size_t buffer_size) FMT_NOEXCEPT {
   FMT_ASSERT(buffer != 0 && buffer_size != 0, "invalid buffer");
 
   class StrError {
@@ -157,8 +157,8 @@ int safe_strerror(
     // Fallback to strerror_s when strerror_r is not available.
     int fallback(int result) {
       // If the buffer is full then the message is probably truncated.
-      return result == 0 && strlen(buffer_) == buffer_size_ - 1 ?
-            ERANGE : result;
+      return result == 0 && strlen(buffer_) == buffer_size_ - 1 ? ERANGE
+                                                                : result;
     }
 
     // Fallback to strerror if strerror_r and strerror_s are not available.
@@ -170,7 +170,7 @@ int safe_strerror(
 
    public:
     StrError(int err_code, char *&buf, std::size_t buf_size)
-      : error_code_(err_code), buffer_(buf), buffer_size_(buf_size) {}
+        : error_code_(err_code), buffer_(buf), buffer_size_(buf_size) {}
 
     int run() {
       // Suppress a warning about unused strerror_r.
@@ -219,14 +219,14 @@ namespace internal {
 
 // This method is used to preserve binary compatibility with fmt 3.0.
 // It can be removed in 4.0.
-FMT_FUNC void format_system_error(
-  Writer &out, int error_code, StringRef message) FMT_NOEXCEPT {
+FMT_FUNC void format_system_error(Writer &out, int error_code,
+                                  StringRef message) FMT_NOEXCEPT {
   fmt::format_system_error(out, error_code, message);
 }
 }  // namespace internal
 
-FMT_FUNC void SystemError::init(
-    int err_code, CStringRef format_str, ArgList args) {
+FMT_FUNC void SystemError::init(int err_code, CStringRef format_str,
+                                ArgList args) {
   error_code_ = err_code;
   MemoryWriter w;
   format_system_error(w, err_code, format(format_str, args));
@@ -235,31 +235,31 @@ FMT_FUNC void SystemError::init(
 }
 
 template <typename T>
-int internal::CharTraits<char>::format_float(
-    char *buffer, std::size_t size, const char *format,
-    unsigned width, int precision, T value) {
+int internal::CharTraits<char>::format_float(char *buffer, std::size_t size,
+                                             const char *format, unsigned width,
+                                             int precision, T value) {
   if (width == 0) {
-    return precision < 0 ?
-        FMT_SNPRINTF(buffer, size, format, value) :
-        FMT_SNPRINTF(buffer, size, format, precision, value);
+    return precision < 0 ? FMT_SNPRINTF(buffer, size, format, value)
+                         : FMT_SNPRINTF(buffer, size, format, precision, value);
   }
-  return precision < 0 ?
-      FMT_SNPRINTF(buffer, size, format, width, value) :
-      FMT_SNPRINTF(buffer, size, format, width, precision, value);
+  return precision < 0
+             ? FMT_SNPRINTF(buffer, size, format, width, value)
+             : FMT_SNPRINTF(buffer, size, format, width, precision, value);
 }
 
 template <typename T>
-int internal::CharTraits<wchar_t>::format_float(
-    wchar_t *buffer, std::size_t size, const wchar_t *format,
-    unsigned width, int precision, T value) {
+int internal::CharTraits<wchar_t>::format_float(wchar_t *buffer,
+                                                std::size_t size,
+                                                const wchar_t *format,
+                                                unsigned width, int precision,
+                                                T value) {
   if (width == 0) {
-    return precision < 0 ?
-        FMT_SWPRINTF(buffer, size, format, value) :
-        FMT_SWPRINTF(buffer, size, format, precision, value);
+    return precision < 0 ? FMT_SWPRINTF(buffer, size, format, value)
+                         : FMT_SWPRINTF(buffer, size, format, precision, value);
   }
-  return precision < 0 ?
-      FMT_SWPRINTF(buffer, size, format, width, value) :
-      FMT_SWPRINTF(buffer, size, format, width, precision, value);
+  return precision < 0
+             ? FMT_SWPRINTF(buffer, size, format, width, value)
+             : FMT_SWPRINTF(buffer, size, format, width, precision, value);
 }
 
 template <typename T>
@@ -270,88 +270,73 @@ const char internal::BasicData<T>::DIGITS[] =
     "6061626364656667686970717273747576777879"
     "8081828384858687888990919293949596979899";
 
-#define FMT_POWERS_OF_10(factor) \
-  factor * 10, \
-  factor * 100, \
-  factor * 1000, \
-  factor * 10000, \
-  factor * 100000, \
-  factor * 1000000, \
-  factor * 10000000, \
-  factor * 100000000, \
-  factor * 1000000000
+#define FMT_POWERS_OF_10(factor)                                             \
+  factor * 10, factor * 100, factor * 1000, factor * 10000, factor * 100000, \
+      factor * 1000000, factor * 10000000, factor * 100000000,               \
+      factor * 1000000000
 
 template <typename T>
 const uint32_t internal::BasicData<T>::POWERS_OF_10_32[] = {
-  0, FMT_POWERS_OF_10(1)
-};
+    0, FMT_POWERS_OF_10(1)};
 
 template <typename T>
 const uint64_t internal::BasicData<T>::POWERS_OF_10_64[] = {
-  0,
-  FMT_POWERS_OF_10(1),
-  FMT_POWERS_OF_10(ULongLong(1000000000)),
-  // Multiply several constants instead of using a single long long constant
-  // to avoid warnings about C++98 not supporting long long.
-  ULongLong(1000000000) * ULongLong(1000000000) * 10
-};
+    0, FMT_POWERS_OF_10(1), FMT_POWERS_OF_10(ULongLong(1000000000)),
+    // Multiply several constants instead of using a single long long constant
+    // to avoid warnings about C++98 not supporting long long.
+    ULongLong(1000000000) * ULongLong(1000000000) * 10};
 
 FMT_FUNC void internal::report_unknown_type(char code, const char *type) {
   (void)type;
   if (std::isprint(static_cast<unsigned char>(code))) {
-    FMT_THROW(FormatError(
-        format("unknown format code '{}' for {}", code, type)));
+    FMT_THROW(
+        FormatError(format("unknown format code '{}' for {}", code, type)));
   }
-  FMT_THROW(FormatError(
-      format("unknown format code '\\x{:02x}' for {}",
-        static_cast<unsigned>(code), type)));
+  FMT_THROW(FormatError(format("unknown format code '\\x{:02x}' for {}",
+                               static_cast<unsigned>(code), type)));
 }
 
 #if FMT_USE_WINDOWS_H
 
 FMT_FUNC internal::UTF8ToUTF16::UTF8ToUTF16(StringRef s) {
-  static const char ERROR_MSG[] = "cannot convert string from UTF-8 to UTF-16.\nString: '{}'";
+  static const char ERROR_MSG[] =
+      "cannot convert string from UTF-8 to UTF-16.\nString: '{}'";
   if (s.size() > INT_MAX)
     FMT_THROW(WindowsError(ERROR_INVALID_PARAMETER, ERROR_MSG, s));
   int s_size = static_cast<int>(s.size());
-  int length = MultiByteToWideChar(
-      CP_UTF8, MB_ERR_INVALID_CHARS, s.data(), s_size, FMT_NULL, 0);
-  if (length == 0)
-    FMT_THROW(WindowsError(GetLastError(), ERROR_MSG,s));
+  int length = MultiByteToWideChar(CP_UTF8, MB_ERR_INVALID_CHARS, s.data(),
+                                   s_size, FMT_NULL, 0);
+  if (length == 0) FMT_THROW(WindowsError(GetLastError(), ERROR_MSG, s));
   buffer_.resize(length + 1);
-  length = MultiByteToWideChar(
-    CP_UTF8, MB_ERR_INVALID_CHARS, s.data(), s_size, &buffer_[0], length);
-  if (length == 0)
-    FMT_THROW(WindowsError(GetLastError(), ERROR_MSG,s));
+  length = MultiByteToWideChar(CP_UTF8, MB_ERR_INVALID_CHARS, s.data(), s_size,
+                               &buffer_[0], length);
+  if (length == 0) FMT_THROW(WindowsError(GetLastError(), ERROR_MSG, s));
   buffer_[length] = 0;
 }
 
 FMT_FUNC internal::UTF16ToUTF8::UTF16ToUTF8(WStringRef s) {
   if (int error_code = convert(s)) {
-    FMT_THROW(WindowsError(error_code,
-        "cannot convert string from UTF-16 to UTF-8"));
+    FMT_THROW(
+        WindowsError(error_code, "cannot convert string from UTF-16 to UTF-8"));
   }
 }
 
 FMT_FUNC int internal::UTF16ToUTF8::convert(WStringRef s) {
-  if (s.size() > INT_MAX)
-    return ERROR_INVALID_PARAMETER;
+  if (s.size() > INT_MAX) return ERROR_INVALID_PARAMETER;
   int s_size = static_cast<int>(s.size());
-  int length = WideCharToMultiByte(
-    CP_UTF8, 0, s.data(), s_size, FMT_NULL, 0, FMT_NULL, FMT_NULL);
-  if (length == 0)
-    return GetLastError();
+  int length = WideCharToMultiByte(CP_UTF8, 0, s.data(), s_size, FMT_NULL, 0,
+                                   FMT_NULL, FMT_NULL);
+  if (length == 0) return GetLastError();
   buffer_.resize(length + 1);
-  length = WideCharToMultiByte(
-    CP_UTF8, 0, s.data(), s_size, &buffer_[0], length, FMT_NULL, FMT_NULL);
-  if (length == 0)
-    return GetLastError();
+  length = WideCharToMultiByte(CP_UTF8, 0, s.data(), s_size, &buffer_[0],
+                               length, FMT_NULL, FMT_NULL);
+  if (length == 0) return GetLastError();
   buffer_[length] = 0;
   return 0;
 }
 
-FMT_FUNC void WindowsError::init(
-    int err_code, CStringRef format_str, ArgList args) {
+FMT_FUNC void WindowsError::init(int err_code, CStringRef format_str,
+                                 ArgList args) {
   error_code_ = err_code;
   MemoryWriter w;
   internal::format_windows_error(w, err_code, format(format_str, args));
@@ -359,17 +344,17 @@ FMT_FUNC void WindowsError::init(
   base = std::runtime_error(w.str());
 }
 
-FMT_FUNC void internal::format_windows_error(
-    Writer &out, int error_code, StringRef message) FMT_NOEXCEPT {
+FMT_FUNC void internal::format_windows_error(Writer &out, int error_code,
+                                             StringRef message) FMT_NOEXCEPT {
   FMT_TRY {
     MemoryBuffer<wchar_t, INLINE_BUFFER_SIZE> buffer;
     buffer.resize(INLINE_BUFFER_SIZE);
     for (;;) {
       wchar_t *system_message = &buffer[0];
       int result = FormatMessageW(
-        FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-        FMT_NULL, error_code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-        system_message, static_cast<uint32_t>(buffer.size()), FMT_NULL);
+          FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, FMT_NULL,
+          error_code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), system_message,
+          static_cast<uint32_t>(buffer.size()), FMT_NULL);
       if (result != 0) {
         UTF16ToUTF8 utf8_message;
         if (utf8_message.convert(system_message) == ERROR_SUCCESS) {
@@ -382,14 +367,15 @@ FMT_FUNC void internal::format_windows_error(
         break;  // Can't get error message, report error code instead.
       buffer.resize(buffer.size() * 2);
     }
-  } FMT_CATCH(...) {}
+  }
+  FMT_CATCH(...) {}
   fmt::format_error_code(out, error_code, message);  // 'fmt::' is for bcc32.
 }
 
 #endif  // FMT_USE_WINDOWS_H
 
-FMT_FUNC void format_system_error(
-    Writer &out, int error_code, StringRef message) FMT_NOEXCEPT {
+FMT_FUNC void format_system_error(Writer &out, int error_code,
+                                  StringRef message) FMT_NOEXCEPT {
   FMT_TRY {
     internal::MemoryBuffer<char, internal::INLINE_BUFFER_SIZE> buffer;
     buffer.resize(internal::INLINE_BUFFER_SIZE);
@@ -404,30 +390,30 @@ FMT_FUNC void format_system_error(
         break;  // Can't get error message, report error code instead.
       buffer.resize(buffer.size() * 2);
     }
-  } FMT_CATCH(...) {}
+  }
+  FMT_CATCH(...) {}
   fmt::format_error_code(out, error_code, message);  // 'fmt::' is for bcc32.
 }
 
 template <typename Char>
 void internal::ArgMap<Char>::init(const ArgList &args) {
-  if (!map_.empty())
-    return;
+  if (!map_.empty()) return;
   typedef internal::NamedArg<Char> NamedArg;
   const NamedArg *named_arg = FMT_NULL;
   bool use_values =
       args.type(ArgList::MAX_PACKED_ARGS - 1) == internal::Arg::NONE;
   if (use_values) {
-    for (unsigned i = 0;/*nothing*/; ++i) {
+    for (unsigned i = 0; /*nothing*/; ++i) {
       internal::Arg::Type arg_type = args.type(i);
       switch (arg_type) {
-      case internal::Arg::NONE:
-        return;
-      case internal::Arg::NAMED_ARG:
-        named_arg = static_cast<const NamedArg*>(args.values_[i].pointer);
-        map_.push_back(Pair(named_arg->name, *named_arg));
-        break;
-      default:
-        /*nothing*/;
+        case internal::Arg::NONE:
+          return;
+        case internal::Arg::NAMED_ARG:
+          named_arg = static_cast<const NamedArg *>(args.values_[i].pointer);
+          map_.push_back(Pair(named_arg->name, *named_arg));
+          break;
+        default:
+            /*nothing*/;
       }
     }
     return;
@@ -435,20 +421,20 @@ void internal::ArgMap<Char>::init(const ArgList &args) {
   for (unsigned i = 0; i != ArgList::MAX_PACKED_ARGS; ++i) {
     internal::Arg::Type arg_type = args.type(i);
     if (arg_type == internal::Arg::NAMED_ARG) {
-      named_arg = static_cast<const NamedArg*>(args.args_[i].pointer);
+      named_arg = static_cast<const NamedArg *>(args.args_[i].pointer);
       map_.push_back(Pair(named_arg->name, *named_arg));
     }
   }
-  for (unsigned i = ArgList::MAX_PACKED_ARGS;/*nothing*/; ++i) {
+  for (unsigned i = ArgList::MAX_PACKED_ARGS; /*nothing*/; ++i) {
     switch (args.args_[i].type) {
-    case internal::Arg::NONE:
-      return;
-    case internal::Arg::NAMED_ARG:
-      named_arg = static_cast<const NamedArg*>(args.args_[i].pointer);
-      map_.push_back(Pair(named_arg->name, *named_arg));
-      break;
-    default:
-      /*nothing*/;
+      case internal::Arg::NONE:
+        return;
+      case internal::Arg::NAMED_ARG:
+        named_arg = static_cast<const NamedArg *>(args.args_[i].pointer);
+        map_.push_back(Pair(named_arg->name, *named_arg));
+        break;
+      default:
+          /*nothing*/;
     }
   }
 }
@@ -458,31 +444,31 @@ void internal::FixedBuffer<Char>::grow(std::size_t) {
   FMT_THROW(std::runtime_error("buffer overflow"));
 }
 
-FMT_FUNC internal::Arg internal::FormatterBase::do_get_arg(
-    unsigned arg_index, const char *&error) {
+FMT_FUNC internal::Arg internal::FormatterBase::do_get_arg(unsigned arg_index,
+                                                           const char *&error) {
   internal::Arg arg = args_[arg_index];
   switch (arg.type) {
-  case internal::Arg::NONE:
-    error = "argument index out of range";
-    break;
-  case internal::Arg::NAMED_ARG:
-    arg = *static_cast<const internal::Arg*>(arg.pointer);
-    break;
-  default:
-    /*nothing*/;
+    case internal::Arg::NONE:
+      error = "argument index out of range";
+      break;
+    case internal::Arg::NAMED_ARG:
+      arg = *static_cast<const internal::Arg *>(arg.pointer);
+      break;
+    default:
+        /*nothing*/;
   }
   return arg;
 }
 
-FMT_FUNC void report_system_error(
-    int error_code, fmt::StringRef message) FMT_NOEXCEPT {
+FMT_FUNC void report_system_error(int error_code,
+                                  fmt::StringRef message) FMT_NOEXCEPT {
   // 'fmt::' is for bcc32.
   report_error(format_system_error, error_code, message);
 }
 
 #if FMT_USE_WINDOWS_H
-FMT_FUNC void report_windows_error(
-    int error_code, fmt::StringRef message) FMT_NOEXCEPT {
+FMT_FUNC void report_windows_error(int error_code,
+                                   fmt::StringRef message) FMT_NOEXCEPT {
   // 'fmt::' is for bcc32.
   report_error(internal::format_windows_error, error_code, message);
 }
@@ -517,12 +503,12 @@ template void internal::FixedBuffer<char>::grow(std::size_t);
 template void internal::ArgMap<char>::init(const ArgList &args);
 
 template FMT_API int internal::CharTraits<char>::format_float(
-    char *buffer, std::size_t size, const char *format,
-    unsigned width, int precision, double value);
+    char *buffer, std::size_t size, const char *format, unsigned width,
+    int precision, double value);
 
 template FMT_API int internal::CharTraits<char>::format_float(
-    char *buffer, std::size_t size, const char *format,
-    unsigned width, int precision, long double value);
+    char *buffer, std::size_t size, const char *format, unsigned width,
+    int precision, long double value);
 
 // Explicit instantiations for wchar_t.
 
@@ -531,19 +517,19 @@ template void internal::FixedBuffer<wchar_t>::grow(std::size_t);
 template void internal::ArgMap<wchar_t>::init(const ArgList &args);
 
 template FMT_API int internal::CharTraits<wchar_t>::format_float(
-    wchar_t *buffer, std::size_t size, const wchar_t *format,
-    unsigned width, int precision, double value);
+    wchar_t *buffer, std::size_t size, const wchar_t *format, unsigned width,
+    int precision, double value);
 
 template FMT_API int internal::CharTraits<wchar_t>::format_float(
-    wchar_t *buffer, std::size_t size, const wchar_t *format,
-    unsigned width, int precision, long double value);
+    wchar_t *buffer, std::size_t size, const wchar_t *format, unsigned width,
+    int precision, long double value);
 
 #endif  // FMT_HEADER_ONLY
 
 }  // namespace fmt
 
 #ifdef _MSC_VER
-# pragma warning(pop)
+#pragma warning(pop)
 #endif
 
 #endif
