@@ -220,17 +220,7 @@ class DataFrame(BaseClass):
 
             values: The values to set.
         """
-        res = self._impl.setColumnPyList(header, list(values))
-        if res != 0:
-            raise NotImplementedError
-        # if any(isinstance(value, basestring) for value in values):
-        #     values = list(map(str, values))
-        #     self._impl.setColumnStr(header, values, len(values))
-        # elif all(isinstance(value, Real) for value in values):
-        #     values = list(map(float, values))
-        #     self._impl.setColumnDbl(header, values, len(values))
-        # else:
-        #     raise NotImplementedError
+        self._impl.setColumnPyList(header, list(values))
 
     def get_row(self, key):
         """
